@@ -17,37 +17,11 @@ def extract_doc(df):
     if not isinstance(df, DataFrame):
         raise UsageError("The variable '{}' is not a pyspark DataFrame".format(df))
     if hasattr(df, 'doc'):
-        output = map_doc_output(df.doc)
-        return remove_not_selected(output)
+        return remove_not_selected(df.doc)
     else:
         return None
 
 
-def map_doc_output(doc_json):
-    def filter_ignored_variables(variable):
-        # Todo - use an ignore field instead
-        return variable['description'] is not None and variable['description'] != ''
-
-    def map_variable(variable):
-        return dict(map(map_variable_field, variable.items()))
-
-    def map_variable_field(variable_field):
-        if type(variable_field[1]) is dict:
-            return variable_field[0], strip_content(variable_field[1])
-        else:
-            return variable_field
-
-    def strip_content(field):
-        names = ('candidates', 'enums')
-        return dict(filter(lambda f: f[0] not in names, field.items()))
-
-    return {
-        'name': doc_json['name'],
-        'description': doc_json['description'],
-        'unitType': strip_content(doc_json['unitType']),
-        'instanceVariables': list(map(map_variable, filter(filter_ignored_variables, doc_json['instanceVariables'])))}
-
-
 def remove_not_selected(doc_json):
     def filter_not_selected_variables(variable):
         def is_enum(value):
@@ -94,18 +68,33 @@ def remove_not_selected(doc_json):
         if variable.__contains__('smart-description'):
             del variable['smart-description']
 
-        return variable['description'] is not None and variable['description'] != ''
+        return True
 
     def map_variable(variable):
         return dict(map(map_variable_field, variable.items()))
 
     def map_variable_field(variable_field):
-        return variable_field
+        if type(variable_field[1]) is dict:
+            return variable_field[0], strip_content(variable_field[1])
+        else:
+            return variable_field
+
+    def get_short_name():
+        if doc_json.__contains__('shortName'):
+            return doc_json['shortName']
+        else:
+            return ""
+
+    def strip_content(field):
+        names = ('candidates', 'enums')
+        return dict(filter(lambda f: f[0] not in names, field.items()))
+
 
     return {
         'name': doc_json['name'],
+        'shortName': get_short_name(),
         'description': doc_json['description'],
-        'unitType': doc_json['unitType'],
+        'unitType': strip_content(doc_json['unitType']),
         'instanceVariables': list(
             map(map_variable, filter(filter_not_selected_variables, doc_json['instanceVariables'])))}
 
@@ -297,11 +286,11 @@ class DaplaDocumentationMagics(Magics):
             return widgets.Box(dropdown, layout=form_item_layout)
 
         for instanceVar in ds.doc['instanceVariables']:
-            variable_titles.append(capitalize_with_camelcase(instanceVar['name']))
+            variable_titles.append(capitalize_with_camelcase(instanceVar['shortName']))
             form_items = []
 
             for key in instanceVar.keys():
-                if key == 'name' or key == 'smart-description':
+                if key == 'shortName':
                     continue
                 form_items.append(
                     create_dropdown_box(instanceVar, capitalize_with_camelcase(key), key)
