@@ -39,7 +39,8 @@ def extract_lineage(df, path, version):
             if hasattr(df, 'lineage'):
                 return map_lineage(df.lineage)
             # Generate simple lineage
-            return get_ipython().run_line_magic(DaplaLineageMagics.lineage_json.__name__, "--path {}".format(path))
+            # Remove this for now, but keep commented out until the fate of linage and smart doc is determined
+            # return get_ipython().run_line_magic(DaplaLineageMagics.lineage_json.__name__, "--path {}".format(path))
         except UsageError:
             # Just skip lineage generation
             return None
